@@ -18,8 +18,9 @@ def create_app():
     app.add_route('/hello/world', HelloWorldResource())
 
     from swagger_ui import api_doc
+
     api_doc(app, config_path=config_path, url_prefix='/api/doc')
     return app
 
 
-uvicorn.run(create_app(), host="0.0.0.0", port=8989, log_level="info")
+uvicorn.run(create_app(), host='0.0.0.0', port=8989, log_level='info')
