@@ -15,6 +15,7 @@ def startup():
     config_path = os.path.join(cur_dir, 'conf/test.yaml')
 
     from swagger_ui import api_doc
+
     api_doc(app, config_path=config_path)
 
 
@@ -25,4 +26,4 @@ routes = [
 app = Starlette(debug=True, routes=routes, on_startup=[startup])
 
 if __name__ == '__main__':
-    uvicorn.run(app, host="0.0.0.0", port=8989, log_level="info")
+    uvicorn.run(app, host='0.0.0.0', port=8989, log_level='info')
